@@ -33,7 +33,7 @@ def create_new_project(session):
 
     clearConsole()
     num = None
-    
+
     if get_yes_no("Do you have a deal number?"):
         while True:
             dealnumber = input("Enter deal number: ")
@@ -44,7 +44,8 @@ def create_new_project(session):
                 continue
             else:
                 if len(dealnumber) == 4:
-                    click.secho(f"Looks like {dealnumber} already existing, try adding to this project instead of creating a new one", fg="yellow")
+                    click.secho(
+                        f"Looks like {dealnumber} already existing, try adding to this project instead of creating a new one", fg="yellow")
                     input("press enter to re-run")
                     quit()
                 if len(dealnumber) == 3:
@@ -128,7 +129,8 @@ def create_new_project(session):
             dest_folder = child
 
     if dest_folder is None:
-        click.secho(f"could not find a 'Projects' folder for team {team['name']}", fg="red")
+        click.secho(
+            f"could not find a 'Projects' folder for team {team['name']}", fg="red")
         quit()
     if client is None:
         while True:
@@ -229,7 +231,9 @@ def create_new_project(session):
     if num_int > 0:
         int_folder = session.create(
             "Folder",
-            {"name": f"{num}_INT", "parent": proj, "thumbnail_id": project_thumb},
+            {"name": f"{num}_INT",
+             "parent": proj,
+             "thumbnail_id": project_thumb}
         )
 
         if len(project_team) > 1:
@@ -330,7 +334,6 @@ def create_new_project(session):
 
     session.commit()
 
-
     print(f"Succesfully created {project_name} for {team['name']}")
     if deal is not None:
         print(f"Based on deal {deal}")
